# FieldReport

Field report commands are used to write a field output report and free body computational results to an ASCII file.

## Create field reports in Session

```{eval-rst}
.. autoclass:: abaqus.FieldReport.FieldReportSession.FieldReportSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.FieldReport
        :recursive:
        :exclude: FieldReportSession
```
